# Abstract........: working scripts to calculate model average betas and predictions for Florida indigo snake data
# Author..........: Eric D. Stolen
# Created.........: October 5 2010
# Modified........: October 22 2013 (Pedro Quintana-Ascencio)

rm(list=ls())
##Set working directory manually or with the following commands##
#getwd
#setwd("insert_your_pathway")

#load data and fix variable types
snake <- read.delim("snake_data.txt", row.names="ID")  # Load a dataframe called snake with data from a file called snake_data.txt

# specify landc and SEX as categorical variables
snake$landc <- factor(snake$landc)
snake$SEX <- factor(snake$SEX)

#create new variables
snake$ha.ln<-log(snake$ha)
snake$lc2<-ifelse(snake$landc==3,2,1)
snake$lc2<- factor(snake$lc2)

#check data
summary(snake)
snake[1:5,]

#load AICcmodavgpackage
library(AICcmodavg)

############################################################################################
################### model selection table and prediction using AICcmodavg #################
   
##prediction using package AICcmodavg

#set-up candidate model set

ms       <- c(                            # Model specification vector, maintains a string description of models to run
              "ha.ln ~ 1 ",
		  "ha.ln ~ SEX ",
              "ha.ln ~ lc2",
              "ha.ln ~ weeks ",
              "ha.ln ~ SEX + lc2",
              "ha.ln ~ SEX + weeks",
              "ha.ln ~ lc2 + weeks",
              "ha.ln ~ SEX + lc2 + weeks"  #no comma at end!
             )
##setup a subset of models of Table 1
Cand.models<-list()
for (i in 1:length(ms)) {
Cand.models[[i]] <- glm(as.formula(ms[i]), family=gaussian, data=snake)
}

##create a vector of names to trace back models in set
Modnames<-paste("model", 1:length(Cand.models), sep="")

##generate AICc table
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
digits = 4, LL = TRUE)

# setting up a data table for predictions
fitdata<-array(c(1,2,1,2,1,1,2,2,52,52,52,52),dim=c(4,3))
fitdata<-data.frame(fitdata)
names(fitdata)[1] <- "SEX"
names(fitdata)[2] <- "lc2"
names(fitdata)[3] <- "weeks"
fitdata$SEX<-factor(fitdata$SEX)
fitdata$lc2<-factor(fitdata$lc2)
fitdata

#get model-averaged predictions
modavgpred(cand.set= Cand.models, modnames= Modnames, newdata=fitdata, type = "link", c.hat = 1, gamdisp = NULL, second.ord = TRUE, nobs = NULL, uncond.se = "revised")


#get model-averaged beta
modavg(cand.set= Cand.models, parm = "lc22", modnames= Modnames)
modavg(cand.set= Cand.models, parm = "SEX2", modnames= Modnames)
modavg(cand.set= Cand.models, parm = "weeks", modnames= Modnames)



